@@ -62,4 +62,11 @@ class WdSyllab(ComplexityIndex):
 
         else:
             logger.error('wrong reduce depth value.')
-        return values
\ No newline at end of file
+        return values
+    
+    def __getstate__(self):
+        return {
+            key: value
+            for key, value in self.__dict__.items()
+            if key != "pyphen"
+        }
\ No newline at end of file
